@@ -4,7 +4,7 @@ use Mojo::Loader;
 use Mojo::Util 'deprecated';
 use XML::Loy;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 my %base_classes;
 
@@ -238,19 +238,19 @@ new ones.
 =head2 register
 
   # Mojolicious
-  $mojo->plugin('XML::Loy' => {
+  $mojo->plugin(XML::Loy => {
     max_size     => 2048,
     new_activity => [-Atom, -ActivityStreams]
   });
 
   # Mojolicious::Lite
-  plugin 'XML::Loy' => {
+  plugin XML::Loy => {
     new_activity => [-Atom, -ActivityStreams]
   };
 
   # In your config file
   {
-    'XML-Loy' => {
+    XML::Loy => {
       new_activity => [-Atom, -ActivityStreams]
     }
   };
@@ -272,7 +272,7 @@ In addition to that, the C<max_size> in bytes of xml documents
 to be parsed can be defined (defaults to C<1024 * 1024>).
 
 All parameters can be set either on registration or
-as part of the configuration file with the key C<XML-Loy>.
+as part of the configuration file with the key C<XML::Loy>.
 
 B<Note:> The C<namespace> parameter is DEPRECATED.
 
